# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.51](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.50...rattler_menuinst-v0.2.51) - 2026-03-18

### Other

- update Cargo.toml dependencies

## [0.2.50](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.49...rattler_menuinst-v0.2.50) - 2026-03-16

### Added

- improve Windows GUI app launching and file extension registration ([#2135](https://github.com/conda/rattler/pull/2135))

## [0.2.49](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.48...rattler_menuinst-v0.2.49) - 2026-02-25

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.48](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.47...rattler_menuinst-v0.2.48) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.47](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.46...rattler_menuinst-v0.2.47) - 2026-02-19

### Other

- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))
- Remove dead struct ([#2048](https://github.com/conda/rattler/pull/2048))

## [0.2.46](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.45...rattler_menuinst-v0.2.46) - 2026-02-04

### Fixed

- Ignore CONDA_SHLVL in tests ([#2029](https://github.com/conda/rattler/pull/2029))

## [0.2.45](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.44...rattler_menuinst-v0.2.45) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.44](https://github.com/baszalmstra/rattler/compare/rattler_menuinst-v0.2.43...rattler_menuinst-v0.2.44) - 2026-01-22

### Other

- updated the following local packages: rattler_shell

## [0.2.43](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.42...rattler_menuinst-v0.2.43) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.42](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.41...rattler_menuinst-v0.2.42) - 2025-12-18

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.2.41](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.40...rattler_menuinst-v0.2.41) - 2025-12-08

### Added

- Add support for `info_plist_extra` property in menuinst ([#1911](https://github.com/conda/rattler/pull/1911))

## [0.2.40](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.39...rattler_menuinst-v0.2.40) - 2025-11-27

### Fixed

- *(menuinst)* respect user-provided CFBundleIdentifier in macOS Info.plist ([#1887](https://github.com/conda/rattler/pull/1887))

## [0.2.39](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.38...rattler_menuinst-v0.2.39) - 2025-11-25

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.38](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.37...rattler_menuinst-v0.2.38) - 2025-11-22

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.37](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.36...rattler_menuinst-v0.2.37) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.36](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.35...rattler_menuinst-v0.2.36) - 2025-11-19

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.35](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.34...rattler_menuinst-v0.2.35) - 2025-11-13

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.34](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.33...rattler_menuinst-v0.2.34) - 2025-10-28

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.33](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.32...rattler_menuinst-v0.2.33) - 2025-10-25

### Other

- updated the following local packages: rattler_shell

## [0.2.32](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.31...rattler_menuinst-v0.2.32) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.31](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.30...rattler_menuinst-v0.2.31) - 2025-10-17

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.30](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.29...rattler_menuinst-v0.2.30) - 2025-10-14

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.29](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.28...rattler_menuinst-v0.2.29) - 2025-10-03

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.28](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.27...rattler_menuinst-v0.2.28) - 2025-09-30

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.27](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.26...rattler_menuinst-v0.2.27) - 2025-09-17

### Fixed

- *(menuinst)* activate menuinst per default ([#1678](https://github.com/conda/rattler/pull/1678))

## [0.2.26](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.25...rattler_menuinst-v0.2.26) - 2025-09-12

### Fixed

- menuinst on linux with `%` command ([#1671](https://github.com/conda/rattler/pull/1671))

## [0.2.25](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.24...rattler_menuinst-v0.2.25) - 2025-09-05

### Fixed

- update correct desktop database when installing packages with shortcuts ([#1656](https://github.com/conda/rattler/pull/1656))

## [0.2.24](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.23...rattler_menuinst-v0.2.24) - 2025-09-02

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.23](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.22...rattler_menuinst-v0.2.23) - 2025-08-28

### Fixed

- *(menuinst)* improve linux ([#1628](https://github.com/conda/rattler/pull/1628))
- *(menuinst)* correct environment variable quoting on Linux ([#1625](https://github.com/conda/rattler/pull/1625))

## [0.2.22](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.21...rattler_menuinst-v0.2.22) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.21](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.20...rattler_menuinst-v0.2.21) - 2025-08-12

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.20](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.19...rattler_menuinst-v0.2.20) - 2025-07-24

### Other

- updated the following local packages: rattler_shell

## [0.2.19](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.18...rattler_menuinst-v0.2.19) - 2025-07-23

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.18](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.17...rattler_menuinst-v0.2.18) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.2.17](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.16...rattler_menuinst-v0.2.17) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.16](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.15...rattler_menuinst-v0.2.16) - 2025-07-09

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.15](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.14...rattler_menuinst-v0.2.15) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.2.14](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.13...rattler_menuinst-v0.2.14) - 2025-06-26

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.13](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.12...rattler_menuinst-v0.2.13) - 2025-06-25

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.12](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.11...rattler_menuinst-v0.2.12) - 2025-06-24

### Other

- *(ci)* Update Rust crate windows to 0.61.0 ([#1462](https://github.com/conda/rattler/pull/1462))

## [0.2.11](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.10...rattler_menuinst-v0.2.11) - 2025-06-23

### Fixed

- use $PATH prepend behavior in `menuinst` activation ([#1376](https://github.com/conda/rattler/pull/1376))

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.2.10](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.9...rattler_menuinst-v0.2.10) - 2025-05-23

### Other

- updated the following local packages: rattler_conda_types, rattler_shell

## [0.2.9](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.8...rattler_menuinst-v0.2.9) - 2025-05-16

### Other

- update dependencies ([#1126](https://github.com/conda/rattler/pull/1126))
- Bump zip to 3.0.0 ([#1310](https://github.com/conda/rattler/pull/1310))

## [0.2.8](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.7...rattler_menuinst-v0.2.8) - 2025-05-03

### Fixed

- menuinst windows shortcut path ([#1273](https://github.com/conda/rattler/pull/1273))

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [0.2.7](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.6...rattler_menuinst-v0.2.7) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [0.2.6](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.5...rattler_menuinst-v0.2.6) - 2025-04-04

### Fixed

- install windows start menu shortcut ([#1198](https://github.com/conda/rattler/pull/1198))

### Other

- change default value of  menuinst windows `quicklaunch` to `false` ([#1196](https://github.com/conda/rattler/pull/1196))

## [0.2.5](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.4...rattler_menuinst-v0.2.5) - 2025-03-18

### Added

- allow to pass a semaphore for concurrency control ([#1169](https://github.com/conda/rattler/pull/1169))

## [0.2.4](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.3...rattler_menuinst-v0.2.4) - 2025-03-14

### Added

- remove menu item and trackers in one function ([#1160](https://github.com/conda/rattler/pull/1160))

## [0.2.3](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.2...rattler_menuinst-v0.2.3) - 2025-03-10

### Other

- update Cargo.toml dependencies

## [0.2.2](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.1...rattler_menuinst-v0.2.2) - 2025-03-04

### Fixed

- shortcut filename ([#1136](https://github.com/conda/rattler/pull/1136))
- create test directories ([#1135](https://github.com/conda/rattler/pull/1135))

## [0.2.1](https://github.com/conda/rattler/compare/rattler_menuinst-v0.2.0...rattler_menuinst-v0.2.1) - 2025-02-28

### Added

- add fake folders method on win for easier testing (#1125)

## [0.2.0](https://github.com/conda/rattler/compare/rattler_menuinst-v0.1.0...rattler_menuinst-v0.2.0) - 2025-02-27

### Added

- Use `opendal` in `rattler-index` and add executable (#1076)

### Fixed

- make `menuinst` schema pub, hide utils, fix indexing for rattler-build (#1111)
- clippy lint (#1105)

## [0.1.0](https://github.com/conda/rattler/releases/tag/rattler_menuinst-v0.1.0) - 2025-02-25

### Added

- add `rattler_menuinst` crate (#840)
- better readme (#118)
- replace zulip with discord (#116)
- move all conda types to separate crate

### Fixed

- release-plz (#1100)
- typos (#849)
- move more links to the conda org from conda-incubator (#816)
- use conda-incubator
- add python docs badge
- typo libsolve -> libsolv (#164)
- change urls from baszalmstra to mamba-org
- build badge

### Other

- fix anchor link (#1035)
- change links from conda-incubator to conda (#813)
- update banner (#808)
- update README.md
- add pixi badge (#563)
- update installation gif
- update banner image
- address issue [#282](https://github.com/conda/rattler/pull/282) ([#283](https://github.com/conda/rattler/pull/283))
- Add an image to Readme ([#203](https://github.com/conda/rattler/pull/203))
- Improve getting started with a micromamba environment. ([#163](https://github.com/conda/rattler/pull/163))
- Misc/update readme ([#66](https://github.com/conda/rattler/pull/66))
- update readme
- layout the vision a little bit better
- *(docs)* add build badge
- matchspec parsing
